Learn R Programming

spcosa (version 0.3-4)

spcosa-package: Spatial Coverage Sampling and Random Sampling from Compact Geographical Strata

Description

Algorithms for spatial coverage sampling and for random sampling from compact geographical strata based on $$k$$-means.

Arguments

Details

The spcosa-package provides algorithms for spatial coverage sampling and for random sampling from compact geographical strata based on $$k$$-means (see de Gruijter et al., 2006, Walvoort et al., 2010, and kmeans). S4-classes and methods are available for spatial coverage sampling, random sampling from compact geographical strata, and stratified simple random sampling for composites. In case of spatial coverage sampling, existing sampling points may be taken into account. See the package vignette for more information and examples.