Learn R Programming

spcosa (version 0.2-2)

spcosa-package: Spatial Coverage Sampling and Random Sampling from Compact Geographical Strata

Description

Algorithms for spatial coverage sampling and for random sampling from compact geographical strata based on $$k$$-means.

Arguments

Details

The spcosa-package provides algorithms for spatial coverage sampling and for random sampling from compact geographical strata based on $$k$$-means (see de Gruijter et al., 2006, and kmeans). S4-classes and methods are available for spatial coverage sampling, random sampling from compact geographical strata, and stratified simple random sampling for composites. In case of spatial coverage sampling, existing sampling points may be taken into account. See the package vignette ([stage=render]{file.path(system.file(package= "spcosa"), "doc", "spcosa.pdf")}) for more information and examples. In order to get the spcosa-package running, make sure that a recent version of Java is installed. The DESCRIPTION file in the package directory tells you which version you minimally need. A more convenient way to obtain version information is to call packageDescription(pkg = "spcosa", fields = "SystemRequirements") at the Rprompt. Free Java downloads are available at http://www.java.com. [object Object],[object Object],[object Object],[object Object] Brus, D. J., Spatjens, L. E. E. M., and de Gruijter, J. J. (1999). A sampling scheme for estimating the mean extractable phosphorus concentration of fields for environmental regulation. Geoderma 89:129-148 de Gruijter, J. J., Brus, D. J., Bierkens, M. F. P., and Knotters, M. (2006). Sampling for Natural Resource Monitoring Berlin: Springer-Verlag. Walvoort, D., Brus, D. and de Gruijter, J. (2009). Spatial Coverage Sampling on Various Spatial Scales. Pedometron 26:20-22 Walvoort, D. J. J., Brus, D. J. and de Gruijter, J. J. (2010). An R package for spatial coverage sampling and random sampling from compact geographical strata by $$k$$-means. Accepted for publication in Computers & Geosciences stratify, spsample, estimate package